/*
 * Copyright 2012 Francesco Cappelli
 *
 * This file is part of Pagliaio.
 *
 * Pagliaio is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Pagliaio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Pagliaio.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONFIGURATION_H_
#define CONFIGURATION_H_

#include <map>
#include <string>

#include <lucene++/LuceneHeaders.h>

namespace pagliaio {

class Configuration {
private:
	class Index {
		public:
		Lucene::Field::Store stored;
		Lucene::Field::Index type;
	};

	std::string defaultField;
	std::string defaultOperator;
	Lucene::Field::Index defaultIndexType;
	Lucene::Field::Store defaultStoring;

	std::map<Lucene::String, Index> indexes;

public:
	Configuration();
	virtual ~Configuration();

	std::string getDefaultField() const {
		return defaultField;
	}

	void setDefaultField(std::string defaultField) {
		this->defaultField = defaultField;
	}

	std::string getDefaultOperator() const {
		return defaultOperator;
	}

	void setDefaultOperator(std::string defaultOperator) {
		this->defaultOperator = defaultOperator;
	}

	Lucene::Field::Index getDefaultIndexType() {
		return this->defaultIndexType;
	}

	Lucene::Field::Store getDefaultStoring() {
		return this->defaultStoring;
	}

	void setDefaultIndexType(std::string type);
	void setDefaultStoring(std::string storing);

	void addIndex(std::string name, bool stored, std::string type);
	void addIndex(Lucene::String name, bool stored, std::string type);
	Lucene::Field::Store indexNeedStoring(std::string name);
	Lucene::Field::Store indexNeedStoring(Lucene::String name);
	Lucene::Field::Index getIndexType(std::string name);
	Lucene::Field::Index getIndexType(Lucene::String name);
};

} /* namespace pagliaio */
#endif /* CONFIGURATION_H_ */
